pub struct ExplorerCut;Trait Implementations
Sourceimpl Clone for ExplorerCut
impl Clone for ExplorerCut
Sourcefn clone(&self) -> ExplorerCut
fn clone(&self) -> ExplorerCut
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CommandTrait for ExplorerCut
impl CommandTrait for ExplorerCut
Sourcefn name(&self) -> &'static str
fn name(&self) -> &'static str
Unique identifier for this command (e.g.,
cursor_up, enter_insert_mode)Sourcefn description(&self) -> &'static str
fn description(&self) -> &'static str
Human-readable description for help/documentation
Sourcefn execute(&self, _ctx: &mut ExecutionContext<'_>) -> CommandResult
fn execute(&self, _ctx: &mut ExecutionContext<'_>) -> CommandResult
Execute the command on the given buffer Read more
Sourcefn valid_modes(&self) -> Option<Vec<ModeState>>
fn valid_modes(&self) -> Option<Vec<ModeState>>
Optional: which modes this command is valid in (None = all modes)
Sourcefn supports_count(&self) -> bool
fn supports_count(&self) -> bool
Optional: does this command support repeat count?
Sourcefn is_jump(&self) -> bool
fn is_jump(&self) -> bool
Whether this command is a “jump” that should be recorded in the jump list Read more
Sourcefn is_text_modifying(&self) -> bool
fn is_text_modifying(&self) -> bool
Whether this command modifies buffer text content Read more
Sourceimpl Debug for ExplorerCut
impl Debug for ExplorerCut
Sourceimpl Default for ExplorerCut
impl Default for ExplorerCut
Sourcefn default() -> ExplorerCut
fn default() -> ExplorerCut
Returns the “default value” for a type. Read more
Sourceimpl Event for ExplorerCut
impl Event for ExplorerCut
impl Copy for ExplorerCut